@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2007 Xavier Claessens <xclaesse@gmail.com>
+ * Copyright (C) 2007 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,6 +16,8 @@
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
+ *
+ * Authors: Xavier Claessens <xclaesse@gmail.com>
  */
 
 #ifndef __EMPATHY_CONTACT_MANAGER_H__
@@ -26,7 +28,7 @@
 #include <libmissioncontrol/mc-account.h>
 
 #include "gossip-contact.h"
-#include "empathy-contact-list.h"
+#include "empathy-tp-contact-list.h"
 
 G_BEGIN_DECLS
 
@@ -51,26 +53,17 @@ struct _EmpathyContactManagerClass {
 
 GType                  empathy_contact_manager_get_type     (void) G_GNUC_CONST;
 EmpathyContactManager *empathy_contact_manager_new          (void);
-void                   empathy_contact_manager_setup        (EmpathyContactManager *manager);
-EmpathyContactList *   empathy_contact_manager_get_list     (EmpathyContactManager *manager,
+EmpathyTpContactList * empathy_contact_manager_get_list     (EmpathyContactManager *manager,
 							     McAccount             *account);
-GossipContact *        empathy_contact_manager_get_own      (EmpathyContactManager *manager,
+GossipContact *        empathy_contact_manager_get_user     (EmpathyContactManager *manager,
 							     McAccount             *account);
-GossipContact *        empathy_contact_manager_find         (EmpathyContactManager *manager,
-							     const gchar           *id);
 GossipContact *        empathy_contact_manager_create       (EmpathyContactManager *manager,
 							     McAccount             *account,
 							     const gchar           *id);
-void                   empathy_contact_manager_add          (EmpathyContactManager *manager,
-							     GossipContact         *contact,
-							     const gchar           *message);
-void                   empathy_contact_manager_remove       (EmpathyContactManager *manager,
-							     GossipContact         *contact);
 void                   empathy_contact_manager_rename_group (EmpathyContactManager *manager,
 							     const gchar           *old_group,
 							     const gchar           *new_group);
 GList *                empathy_contact_manager_get_groups   (EmpathyContactManager *manager);
-GList *                empathy_contact_manager_get_contacts (EmpathyContactManager *manager);
 
 G_END_DECLS
 
