@@ -44,7 +44,7 @@ main (int argc, char *argv[])
 
 	gtk_init (&argc, &argv);
 
-	dialog = gossip_accounts_dialog_show ();
+	dialog = gossip_accounts_dialog_show (NULL);
 
 	g_signal_connect (dialog, "destroy",
 			  G_CALLBACK (destroy_cb),
